==> hoteldruid-mod-sv_3.0.1-1.zip: sv/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "L&auml;gg till &ouml;verl&aring;telsereglerna f&ouml;r reservationer &aring;r"; break;
case "Regola di assegnazione":  		$messaggio = "&Ouml;verl&aring;telseregel"; break;
case "nel periodo dal":  			$messaggio = " under perioden fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "motivazione":  				$messaggio = "motivering"; break;
case "Inserisci la regola":  			$messaggio = "L&auml;gg till regel"; break;
case "Inserisci o modifica la regola":  	$messaggio = "L&auml;gg till eller modifiera regel"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Ta bort alla regler av den h&auml;r sorten"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "N&auml;r pris v&auml;ljs"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "om ingen annan tilldelningsmetod &auml;r vald"; break;
case "Vedi le regole già inserite":  		$messaggio = "Se redan tillagda regler"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Alla n&ouml;dv&auml;ndiga data har inte lagts till"; break;
case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "opzionale":  				$messaggio = "valfri"; break;
case "La regola è stata inserita":  		$messaggio = "Regeln har lagts till"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill ta bort alla regler av typ 1"; break;
case "SI":  					$messaggio = "JA"; break;
case "Le regole sono state cancellate":  	$messaggio = "Reglerna har tagits bort"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Du m&aring;ste v&auml;lja pris"; break;
case " non esiste":  				$messaggio = " finns inte"; break;
case "La regola di assegnazione":		$messaggio = "&Ouml;verl&aring;telseregeln"; break;
case "è stata inserita":			$messaggio = "har lagts till"; break;
case "è stata modificata":			$messaggio = "har &auml;ndrats"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Motivazione non valida":  		$messaggio = "Icke till&aring;ten motivering"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Valt pris har redan en tilldelad anv&auml;ndare. Ta bort regeln innan en ny l&auml;ggs till"; break;
case "Quando l'utente amministratore":  	$messaggio = "N&auml;r administrat&ouml;ren"; break;
case "sceglie la tariffa":  			$messaggio = "v&auml;ljer pris"; break;
case "fai risultare come se l'utente":  	$messaggio = "visa som om anv&auml;ndaren"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "har lagt ill reservationen och den slutliga kunden"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Du m&aring;ste v&auml;lja anv&auml;ndaren som ska associeras"; break;
case "L'utente ":  				$messaggio = "Anv&auml;ndaren "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "automatiskt tilldela som antal personer"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "om inga andra rum har lagts till"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Valt pris har redan ett tilldelat antal personer. Ta bort regeln f&ouml;re en ny l&auml;ggs till"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Du m&aring;ste v&auml;lja antalet personer som ska associeras"; break;
case "Crea Regole":  				$messaggio = "Create Rules"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "Regole esistenti":  			$messaggio = "Existing rules"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Ridimensiona":  				$messaggio = "Scale down"; break;
case "Modifica la regola":  			$messaggio = "Modify rule"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_3.0.8-1.zip: sv/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "L&auml;gg till &ouml;verl&aring;telsereglerna f&ouml;r reservationer &aring;r"; break;
case "Regola di assegnazione":  		$messaggio = "&Ouml;verl&aring;telseregel"; break;
case "nel periodo dal":  			$messaggio = " under perioden fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "motivazione":  				$messaggio = "motivering"; break;
case "Inserisci la regola":  			$messaggio = "L&auml;gg till regel"; break;
case "Inserisci o modifica la regola":  	$messaggio = "L&auml;gg till eller modifiera regel"; break;
case "Cancella tutte le regole di questo tipo":	$messaggio = "Ta bort alla regler av den h&auml;r sorten"; break;
case "Quando si sceglie la tariffa":  		$messaggio = "N&auml;r pris v&auml;ljs"; break;
case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "om ingen annan tilldelningsmetod &auml;r vald"; break;
case "Vedi le regole già inserite":  		$messaggio = "Se redan tillagda regler"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Alla n&ouml;dv&auml;ndiga data har inte lagts till"; break;
case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "opzionale":  				$messaggio = "valfri"; break;
case "La regola è stata inserita":  		$messaggio = "Regeln har lagts till"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill ta bort alla regler av typ 1"; break;
case "SI":  					$messaggio = "JA"; break;
case "Le regole sono state cancellate":  	$messaggio = "Reglerna har tagits bort"; break;
case "Si deve scegliere la tariffa":  		$messaggio = "Du m&aring;ste v&auml;lja pris"; break;
case " non esiste":  				$messaggio = " finns inte"; break;
case "La regola di assegnazione":		$messaggio = "&Ouml;verl&aring;telseregeln"; break;
case "è stata inserita":			$messaggio = "har lagts till"; break;
case "è stata modificata":			$messaggio = "har &auml;ndrats"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Motivazione non valida":  		$messaggio = "Icke till&aring;ten motivering"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Valt pris har redan en tilldelad anv&auml;ndare. Ta bort regeln innan en ny l&auml;ggs till"; break;
case "Quando l'utente amministratore":  	$messaggio = "N&auml;r administrat&ouml;ren"; break;
case "sceglie la tariffa":  			$messaggio = "v&auml;ljer pris"; break;
case "fai risultare come se l'utente":  	$messaggio = "visa som om anv&auml;ndaren"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "har lagt ill reservationen och den slutliga kunden"; break;
case "Si deve inserire l'utente da associare":	$messaggio = "Du m&aring;ste v&auml;lja anv&auml;ndaren som ska associeras"; break;
case "L'utente ":  				$messaggio = "Anv&auml;ndaren "; break;
case "assegna automaticamente come numero di persone":	$messaggio = "automatiskt tilldela som antal personer"; break;
case "se non si inserisce nessun altro numero":	$messaggio = "om inga andra rum har lagts till"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Valt pris har redan ett tilldelat antal personer. Ta bort regeln f&ouml;re en ny l&auml;ggs till"; break;
case "Si deve inserire il numero di persone da associare":	$messaggio = "Du m&aring;ste v&auml;lja antalet personer som ska associeras"; break;
case "Crea Regole":  				$messaggio = "Create Rules"; break;
case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
case "e mancano meno di":  			$messaggio = " and less than"; break;
case "giorni":					$messaggio = "days are missing"; break;
case "dall'inizio":				$messaggio = "from the beginning"; break;
case "dalla fine":				$messaggio = "from the ending"; break;
case "della prenotazione quando essa viene inserita, allora":	$messaggio = "of the reservation when it is inserted, then"; break;
case "Inserisci o modifica questa eccezione alla regola":	$messaggio = "Insert or modify this exception to rule"; break;
case "Si deve inserire il numero di giorni":  	$messaggio = "The number of days must be inserted"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "Regole esistenti":  			$messaggio = "Existing rules"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Ridimensiona":  				$messaggio = "Scale down"; break;
case "Modifica la regola":  			$messaggio = "Modify rule"; break;
case "chiusure":  				$messaggio = "closures"; break;
case "numero di persone":  			$messaggio = "number of people"; break;
case "utente inserimento":  			$messaggio = "inserting user"; break;
case "non permettere l'inserimento di prenotazioni con meno di":	$messaggio = "do not allow inserting reservations with less than"; break;
case "Il numero di persone minimo":  		$messaggio = "The minimum number of people"; break;
case "è maggiore del numero di persone predefinito":	$messaggio = "is bigger then the default number of people"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
